==> bea_flutter_package-1.2.0.tar.gz: lib/bea_services/dtos/bea_models/base_models/layout/get_layout_by_role_id_output.dart <==
class GetLayoutByRoleIdOutput {
  List<Categories> categories;

  GetLayoutByRoleIdOutput({this.categories});

  GetLayoutByRoleIdOutput.fromJson(Map<String, dynamic> json) {
    if (json['categories'] != null) {
      categories = new List<Categories>();
      json['categories'].forEach((v) {
        categories.add(new Categories.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.categories != null) {
      data['categories'] = this.categories.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Categories {
  String id;
  String image;
  String backgroundColor;
  bool isCustom;
  int order;
  String label;
  String description;
  List<Module> modules;

  Categories(
      {this.id,
        this.image,
        this.backgroundColor,
        this.isCustom,
        this.order,
        this.label,
        this.description,
        this.modules});

  Categories.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    image = json['image'];
    backgroundColor = json['backgroundColor'];
    isCustom = json['isCustom'];
    order = json['order'];
    label = json['label'];
    description = json['description'];
    if (json['modules'] != null) {
      modules = new List<Module>();
      json['modules'].forEach((v) {
        modules.add(new Module.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['image'] = this.image;
    data['backgroundColor'] = this.backgroundColor;
    data['isCustom'] = this.isCustom;
    data['order'] = this.order;
    data['label'] = this.label;
    data['description'] = this.description;
    if (this.modules != null) {
      data['modules'] = this.modules.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Module {
  String id;
  String image;
  String backgroundColor;
  bool isCustom;
  int order;
  String label;
  String description;
  int favorite;
  String customJs;
  bool isDetail;
  String message;
  String iconColor;

  Module(
      {this.id,
        this.image,
        this.backgroundColor,
        this.isCustom,
        this.order,
        this.label,
        this.description,
        this.favorite,
        this.customJs,
        this.isDetail,
        this.message,
        this.iconColor});

  Module.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    image = json['image'];
    backgroundColor = json['backgroundColor'];
    isCustom = json['isCustom'];
    order = json['order'];
    label = json['label'];
    description = json['description'];
    favorite = json['favorite'];
    customJs = json['customJs'];
    isDetail = json['isDetail'];
    message = json['message'];
    iconColor = json['iconColor'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['image'] = this.image;
    data['backgroundColor'] = this.backgroundColor;
    data['isCustom'] = this.isCustom;
    data['order'] = this.order;
    data['label'] = this.label;
    data['description'] = this.description;
    data['favorite'] = this.favorite;
    data['customJs'] = this.customJs;
    data['isDetail'] = this.isDetail;
    data['message'] = this.message;
    data['iconColor'] = this.iconColor;
    return data;
  }
}

==> bea_flutter_package-2.0.0.tar.gz: lib/bea_services/dtos/bea_models/base_models/layout/get_layout_by_role_id_output.dart <==
class GetLayoutByRoleIdOutput {
  List<Categories>? categories;

  GetLayoutByRoleIdOutput({this.categories});

  GetLayoutByRoleIdOutput.fromJson(Map<String, dynamic> json) {
    if (json['categories'] != null) {
      categories = [];
      json['categories'].forEach((v) {
        categories!.add(new Categories.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.categories != null) {
      data['categories'] = this.categories!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Categories {
  String? id;
  String? image;
  String? backgroundColor;
  bool? isCustom;
  int? order;
  String? label;
  String? description;
  List<Module>? modules;

  Categories(
      {this.id,
        this.image,
        this.backgroundColor,
        this.isCustom,
        this.order,
        this.label,
        this.description,
        this.modules});

  Categories.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    image = json['image'];
    backgroundColor = json['backgroundColor'];
    isCustom = json['isCustom'];
    order = json['order'];
    label = json['label'];
    description = json['description'];
    if (json['modules'] != null) {
      modules = [];
      json['modules'].forEach((v) {
        modules!.add(new Module.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['image'] = this.image;
    data['backgroundColor'] = this.backgroundColor;
    data['isCustom'] = this.isCustom;
    data['order'] = this.order;
    data['label'] = this.label;
    data['description'] = this.description;
    if (this.modules != null) {
      data['modules'] = this.modules!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Module {
  String? id;
  String? image;
  String? backgroundColor;
  bool? isCustom;
  int? order;
  String? label;
  String? description;
  int? favorite;
  String? customJs;
  bool? isDetail;
  String? message;
  String? iconColor;

  Module(
      {this.id,
        this.image,
        this.backgroundColor,
        this.isCustom,
        this.order,
        this.label,
        this.description,
        this.favorite,
        this.customJs,
        this.isDetail,
        this.message,
        this.iconColor});

  Module.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    image = json['image'];
    backgroundColor = json['backgroundColor'];
    isCustom = json['isCustom'];
    order = json['order'];
    label = json['label'];
    description = json['description'];
    favorite = json['favorite'];
    customJs = json['customJs'];
    isDetail = json['isDetail'];
    message = json['message'];
    iconColor = json['iconColor'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['image'] = this.image;
    data['backgroundColor'] = this.backgroundColor;
    data['isCustom'] = this.isCustom;
    data['order'] = this.order;
    data['label'] = this.label;
    data['description'] = this.description;
    data['favorite'] = this.favorite;
    data['customJs'] = this.customJs;
    data['isDetail'] = this.isDetail;
    data['message'] = this.message;
    data['iconColor'] = this.iconColor;
    return data;
  }
}
